function  [tarray, zarray]   = myEulerSolver(eqn, tarray, z0, p)
%Solves ODEs using Euler's method
% eqn is the name of the RHS file.
ntimes = length(tarray);     % number of times to evaluate
zarray = zeros(ntimes, length(z0));  % Memory allocation 
zarray(1,:) = z0';     % set first row to ICs

for i  = 2:ntimes     % Once through the loop for each time interval
   h    = tarray(i) - tarray(i-1);       % size of time step
   z    = zarray(i-1,:)';   t = tarray(i);  % set present values
   zdot = eqn(t,z,p);     % evaluate RSH (right hand side) at present time
     % The heart of this whole Script is the next line of code
     %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     znew = z + zdot * h;   % one Euler-method time step.
     %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   zarray(i,:) = znew'; % Add a row to the array of solutions. 
                        % Recall, z is a column, zarray is in rows.
 end % loop
end  % function
