function  [tarray, zarray]   = myMidpointSolver(eqn, tarray, z0, p)
%Solves ODEs using midpoint (2n order RK) method
% eqn is the name of the RHS file
ntimes = length(tarray);     % number of times
zarray = zeros(ntimes, length(z0));  % Memory allocation
zarray(1,:) = z0';     % Set first row of soln to the ICs

for i  = 2:ntimes     % Once through the loop for each time interval
   h    = tarray(i) - tarray(i-1);       % size of time step
   z    = zarray(i-1,:)';   t = tarray(i);  % set present values
   
   %Midpoint method is the next four lines of code
   zdot = eqn(t,z,p);     % evaluate RSH (right hand side) at present time
    ztemp = z + zdot * h/2;   % half of one Euler-method time step.
   zdot = eqn(t+h/2,ztemp,p); % evaluate RHS (right hand side) at midpoint
   znew = z + zdot * h;   % one Midpoint-method time step.
 
   zarray(i,:) = znew'; % Add a row to the array of solutions. 
                        % Recall, z is a column, zarray is in rows.
 end % loop
end  % function
